@@ -26,6 +26,29 @@ class TioneClient(AbstractClient):
     _service = 'tione'
 
 
+    def ChatCompletion(self, request):
+        """与大模型聊天
+
+        :param request: Request instance for ChatCompletion.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ChatCompletionRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ChatCompletionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChatCompletion", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChatCompletionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateBatchModelAccTasks(self, request):
         """批量创建模型加速任务
 
@@ -46,7 +69,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateBatchTask(self, request):
@@ -69,7 +92,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateDataset(self, request):
@@ -92,7 +115,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateModelService(self, request):
@@ -115,7 +138,53 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateNotebook(self, request):
+        """创建Notebook
+
+        :param request: Request instance for CreateNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.CreateNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.CreateNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateNotebookImage(self, request):
+        """保存镜像
+
+        :param request: Request instance for CreateNotebookImage.
+        :type request: :class:`tencentcloud.tione.v20211111.models.CreateNotebookImageRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.CreateNotebookImageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateNotebookImage", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateNotebookImageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateOptimizedModel(self, request):
@@ -138,7 +207,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTrainingModel(self, request):
@@ -161,7 +230,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTrainingTask(self, request):
@@ -184,7 +253,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteBatchTask(self, request):
@@ -207,7 +276,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteDataset(self, request):
@@ -230,7 +299,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteModelAccelerateTask(self, request):
@@ -253,7 +322,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteModelService(self, request):
@@ -276,7 +345,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteModelServiceGroup(self, request):
@@ -299,7 +368,53 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteNotebook(self, request):
+        """删除Notebook
+
+        :param request: Request instance for DeleteNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DeleteNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DeleteNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteNotebookImageRecord(self, request):
+        """删除notebook镜像保存记录
+
+        :param request: Request instance for DeleteNotebookImageRecord.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DeleteNotebookImageRecordRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DeleteNotebookImageRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteNotebookImageRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteNotebookImageRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTrainingModel(self, request):
@@ -322,7 +437,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTrainingModelVersion(self, request):
@@ -345,7 +460,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTrainingTask(self, request):
@@ -368,7 +483,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAPIConfigs(self, request):
@@ -391,7 +506,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBatchTask(self, request):
@@ -414,7 +529,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBatchTaskInstances(self, request):
@@ -437,7 +552,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBatchTasks(self, request):
@@ -460,7 +575,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBillingResourceGroups(self, request):
@@ -483,7 +598,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBillingSpecs(self, request):
@@ -506,7 +621,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBillingSpecsPrice(self, request):
@@ -529,7 +644,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDatasetDetailStructured(self, request):
@@ -552,7 +667,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDatasetDetailUnstructured(self, request):
@@ -575,7 +690,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDatasets(self, request):
@@ -598,7 +713,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeInferTemplates(self, request):
@@ -621,7 +736,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLatestTrainingMetrics(self, request):
@@ -644,7 +759,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeLogs(self, request):
@@ -667,7 +782,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelAccEngineVersions(self, request):
@@ -690,7 +805,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelAccelerateTask(self, request):
@@ -713,7 +828,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelAccelerateTasks(self, request):
@@ -736,7 +851,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelService(self, request):
@@ -759,7 +874,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServiceCallInfo(self, request):
@@ -782,7 +897,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServiceGroup(self, request):
@@ -805,7 +920,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServiceGroups(self, request):
@@ -828,7 +943,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServiceHistory(self, request):
@@ -851,7 +966,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServiceHotUpdated(self, request):
@@ -874,7 +989,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeModelServices(self, request):
@@ -897,7 +1012,99 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeNotebook(self, request):
+        """Notebook详情
+
+        :param request: Request instance for DescribeNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeNotebookImageKernels(self, request):
+        """查询镜像kernel
+
+        :param request: Request instance for DescribeNotebookImageKernels.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookImageKernelsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookImageKernelsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNotebookImageKernels", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNotebookImageKernelsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeNotebookImageRecords(self, request):
+        """查看notebook镜像保存记录
+
+        :param request: Request instance for DescribeNotebookImageRecords.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookImageRecordsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeNotebookImageRecordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNotebookImageRecords", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNotebookImageRecordsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeNotebooks(self, request):
+        """Notebook列表
+
+        :param request: Request instance for DescribeNotebooks.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeNotebooksRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeNotebooksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNotebooks", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNotebooksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingFrameworks(self, request):
@@ -920,7 +1127,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingMetrics(self, request):
@@ -943,7 +1150,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingModelVersion(self, request):
@@ -966,7 +1173,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingModelVersions(self, request):
@@ -989,7 +1196,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingModels(self, request):
@@ -1012,7 +1219,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingTask(self, request):
@@ -1035,7 +1242,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingTaskPods(self, request):
@@ -1058,7 +1265,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrainingTasks(self, request):
@@ -1081,7 +1288,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyModelService(self, request):
@@ -1104,7 +1311,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyModelServicePartialConfig(self, request):
@@ -1127,7 +1334,53 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyNotebook(self, request):
+        """修改Notebook
+
+        :param request: Request instance for ModifyNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyNotebookTags(self, request):
+        """修改Notebook标签
+
+        :param request: Request instance for ModifyNotebookTags.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookTagsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookTagsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyNotebookTags", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyNotebookTagsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyServiceGroupWeights(self, request):
@@ -1150,7 +1403,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PushTrainingMetrics(self, request):
@@ -1173,7 +1426,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def RestartModelAccelerateTask(self, request):
@@ -1196,7 +1449,30 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StartNotebook(self, request):
+        """启动Notebook
+
+        :param request: Request instance for StartNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.StartNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.StartNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StartTrainingTask(self, request):
@@ -1219,7 +1495,7 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopBatchTask(self, request):
@@ -1242,7 +1518,30 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopCreatingImage(self, request):
+        """停止保存镜像
+
+        :param request: Request instance for StopCreatingImage.
+        :type request: :class:`tencentcloud.tione.v20211111.models.StopCreatingImageRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.StopCreatingImageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopCreatingImage", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopCreatingImageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopModelAccelerateTask(self, request):
@@ -1265,7 +1564,30 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopNotebook(self, request):
+        """停止Notebook
+
+        :param request: Request instance for StopNotebook.
+        :type request: :class:`tencentcloud.tione.v20211111.models.StopNotebookRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.StopNotebookResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopNotebook", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopNotebookResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopTrainingTask(self, request):
@@ -1288,4 +1610,4 @@ class TioneClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
